@@ -24,6 +24,8 @@ import multiprocessing as mp
 
 import numpy as np
 import pyproj
+from pyproj import CRS
+from pyproj.enums import TransformDirection
 
 try:
     import numexpr as ne
@@ -31,6 +33,7 @@ except ImportError:
     ne = None
 
 from ._multi_proc import Scheduler, shmem_as_ndarray
+from .utils.proj4 import get_geodetic_crs_with_no_datum_shift
 
 # Earth radius
 R = 6370997.0
@@ -185,7 +188,7 @@ def _run_jobs(target, args, nprocs):
         p.join()
     if ierr.value != 0:
         raise RuntimeError('%d errors in worker processes. Last one reported:\n%s' %
-                           (ierr.value, warn_msg.value.decode()))
+                           (ierr.value, warn_msg.value._object_hook()))
 
 # This is executed in an external process:
 
@@ -238,12 +241,16 @@ def _parallel_proj(scheduler, data1, data2, res1, res2, proj_args, proj_kwargs,
         _res2 = shmem_as_ndarray(res2)
 
         # Initialise pyproj
-        proj = pyproj.Proj(*proj_args, **proj_kwargs)
+        proj_def = proj_args[0] if proj_args else proj_kwargs
+        crs = CRS.from_user_input(proj_def)
+        gcrs = get_geodetic_crs_with_no_datum_shift(crs)
+        transformer = pyproj.Transformer.from_crs(gcrs, crs, always_xy=True)
+        trans_kwargs = {"radians": radians, "errcheck": errcheck,
+                        "direction": TransformDirection.INVERSE if inverse else TransformDirection.FORWARD}
 
         # Reproject data segment
         for s in scheduler:
-            _res1[s], _res2[s] = proj(_data1[s], _data2[s], inverse=inverse,
-                                      radians=radians, errcheck=errcheck)
+            _res1[s], _res2[s] = transformer.transform(_data1[s], _data2[s], **trans_kwargs)
 
     # An error occured, increment the return value ierr.
     # Access to ierr is serialized by multiprocessing.
